<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>FeatherPad::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="175"/>
        <source>License</source>
        <translation>ლიცენზია</translation>
    </message>
</context>
<context>
    <name>FeatherPad::FPwin</name>
    <message>
        <location filename="../../fpwin.cpp" line="452"/>
        <location filename="../../fpwin.cpp" line="1574"/>
        <location filename="../../fpwin.cpp" line="1627"/>
        <location filename="../../fpwin.cpp" line="2246"/>
        <location filename="../../fpwin.cpp" line="2308"/>
        <location filename="../../fpwin.cpp" line="3077"/>
        <location filename="../../fpwin.cpp" line="3097"/>
        <location filename="../../fpwin.cpp" line="3100"/>
        <location filename="../../fpwin.cpp" line="4044"/>
        <location filename="../../fpwin.cpp" line="4737"/>
        <location filename="../../fpwin.cpp" line="5032"/>
        <location filename="../../fpwin.cpp" line="5293"/>
        <source>Untitled</source>
        <translation>უსათაურო</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="71"/>
        <source>Go to line:</source>
        <translation>გადასვლა ხაზზე:</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="107"/>
        <source>Select text from cursor to this line
(Ctrl+Shift+J)</source>
        <translation>ტექსტის მონიშვნა კურსორიდან ამ ხაზამდე
(Ctrl+Shift+J)</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="111"/>
        <source>Select Text</source>
        <translation>ტექსტის მონიშვნა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="114"/>
        <source>Ctrl+Shift+J</source>
        <translation>Ctrl+Shift+J</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="149"/>
        <source>&amp;File</source>
        <translation>&amp;ფაილი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="189"/>
        <location filename="../../fp.ui" line="787"/>
        <source>&amp;Edit</source>
        <translation>&amp;ჩასწორება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="219"/>
        <source>&amp;Options</source>
        <translation>&amp;მორგება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2977"/>
        <location filename="../../fpwin.cpp" line="4548"/>
        <source>Encoding</source>
        <translation>კოდირება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="242"/>
        <source>&amp;Search</source>
        <translation>&amp;ძებნა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="250"/>
        <location filename="../../fp.ui" line="709"/>
        <source>&amp;Help</source>
        <translation>&amp;დახმარება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="353"/>
        <source>Find:</source>
        <translation>მოძებნა:</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="369"/>
        <source>To be replaced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="382"/>
        <source>Replace with:</source>
        <translation>ჩანაცვლდება:</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="398"/>
        <source>Replacing text</source>
        <translation>ტექსტის ჩანაცვლება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="457"/>
        <source>&amp;New</source>
        <translation>&amp;ახალი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="460"/>
        <source>New tab</source>
        <translation>ახალი ჩანართი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="463"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="468"/>
        <source>&amp;Open</source>
        <translation>&amp;გახსნა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="471"/>
        <source>Open a file</source>
        <translation>ფაილის გახსნა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="474"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="482"/>
        <location filename="../../fpwin.cpp" line="1367"/>
        <source>&amp;Save</source>
        <translation>&amp;შენახვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="485"/>
        <source>Save the current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="488"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="496"/>
        <source>&amp;Undo</source>
        <translation>&amp;დაბრუნება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="499"/>
        <source>Undo</source>
        <translation>დაბრუნება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="502"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="510"/>
        <source>&amp;Redo</source>
        <translation>&amp;თავიდან</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="513"/>
        <source>Redo</source>
        <translation>გამეორება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="516"/>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="524"/>
        <location filename="../../fp.ui" line="527"/>
        <source>Reload</source>
        <translation>თავიდან ჩატვირთვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="530"/>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="535"/>
        <source>&amp;Find</source>
        <translation>&amp;ძებნა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="541"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="549"/>
        <source>Show/hide replacement dock</source>
        <translation>ჩანაცვლების პანელის ჩვენება/დამალვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="552"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="557"/>
        <source>Save &amp;As</source>
        <translation>შენახვა როგორც</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="560"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="565"/>
        <source>&amp;Print</source>
        <translation>&amp;ბეჭდვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="568"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="573"/>
        <source>Documen&amp;t Properties</source>
        <translation>დოკუმენ&amp;ტის თვისებები</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="576"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="581"/>
        <source>&amp;Close</source>
        <translation>&amp;დახურვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="584"/>
        <source>Ctrl+Shift+Q</source>
        <translation>Ctrl+Shift+Q</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="589"/>
        <source>&amp;Quit</source>
        <translation>გამოსვლა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="592"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="600"/>
        <source>&amp;Cut</source>
        <translation>&amp;ამოჭრა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="603"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="611"/>
        <source>C&amp;opy</source>
        <translation>&amp;კოპირება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="614"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="619"/>
        <source>&amp;Paste</source>
        <translation>&amp;ჩასმა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="622"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="630"/>
        <source>&amp;Delete</source>
        <translation>&amp;წაშლა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="635"/>
        <source>&amp;Select All</source>
        <translation>ყვე&amp;ლაფრის მონიშვნა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="638"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="643"/>
        <source>&amp;Font</source>
        <translation>&amp;ფონტი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="651"/>
        <source>&amp;Line Numbers</source>
        <translation>&amp;ხაზის ნომრები</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="654"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="665"/>
        <source>&amp;Wrap Lines</source>
        <translation>&amp;ხაზების გადატანა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="668"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="679"/>
        <source>&amp;Auto-Indentation</source>
        <translation>&amp;ავტოშეწევა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="682"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="693"/>
        <source>&amp;Syntax Highlighting</source>
        <translation>&amp;სინტაქსის გამოკვეთა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="696"/>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="701"/>
        <source>&amp;Preferences</source>
        <translation>&amp;გამართვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="704"/>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="712"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="717"/>
        <source>&amp;About</source>
        <translation>&amp;შესახებ</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="733"/>
        <source>Enforce UTF-8</source>
        <translation>UTF-8 ნაძალადევად</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="771"/>
        <source>Save with &amp;Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="776"/>
        <source>&amp;Jump to</source>
        <translation>&amp;გადასვლა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="779"/>
        <source>Show/hide jump bar</source>
        <translation>გადასვლის პანელის ჩვენება/დამალვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="782"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="790"/>
        <source>Edit text</source>
        <translation>ტექსტის ჩასწორება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="793"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="888"/>
        <source>&amp;Run</source>
        <translation>&amp;გაშვება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="894"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="899"/>
        <source>&amp;Clear</source>
        <translation>&amp;გასუფთავება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="902"/>
        <source>Clear the list of recently modified files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="910"/>
        <source>Save/Restore Session</source>
        <translation>სესიის შენახვა/აღდგენა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="907"/>
        <source>Sa&amp;ve/Restore Session</source>
        <translation>სესიის შენახ&amp;ვა/აღდგენა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="913"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="918"/>
        <source>Side-Pane</source>
        <translation>გვერდითი პანელი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="921"/>
        <source>Ctrl+Alt+P</source>
        <translation>Ctrl+Alt+P</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="926"/>
        <source>Paste Date and Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="929"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="934"/>
        <location filename="../../fp.ui" line="937"/>
        <source>To Upper Case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="940"/>
        <source>Ctrl+Shift+U</source>
        <translation>Ctrl+Shift+U</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="945"/>
        <location filename="../../fp.ui" line="948"/>
        <source>To Lower Case</source>
        <translation>პატარა ასოებში</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="951"/>
        <source>Ctrl+Shift+L</source>
        <translation>Ctrl+Shift+L</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="956"/>
        <location filename="../../fp.ui" line="959"/>
        <source>To Start Case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="967"/>
        <location filename="../../fp.ui" line="970"/>
        <source>Last Active Tab</source>
        <translation>ბოლო აქტიური ჩანართი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="973"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="978"/>
        <location filename="../../fp.ui" line="981"/>
        <source>Sort Lines</source>
        <translation>ხაზების დალაგება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="986"/>
        <location filename="../../fp.ui" line="989"/>
        <source>Sort Lines Reversely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="994"/>
        <source>Check Spelling</source>
        <translation>მართლწერის შემოწმება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="997"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="1002"/>
        <location filename="../../fp.ui" line="1005"/>
        <source>Save All Files</source>
        <translation>ყველა ფაილის შენახვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="1010"/>
        <location filename="../../fp.ui" line="1013"/>
        <source>User Dictionary</source>
        <translation>მომხმარებლის ლექსიკონი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="1018"/>
        <source>Text Tabs to Spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="801"/>
        <source>&amp;Detach Tab</source>
        <translation>&amp;ჩანართის მოხსნა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="804"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="809"/>
        <source>Close Ne&amp;xt Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="814"/>
        <source>Close &amp;Previous Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="842"/>
        <source>Ne&amp;xt Tab</source>
        <translation>შემდეგი ჩანა&amp;რთი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="853"/>
        <source>Previous Ta&amp;b</source>
        <translation>&amp;წინა ჩანართი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="891"/>
        <source>Execute</source>
        <translation>შესრულება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="819"/>
        <source>Close &amp;All Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="153"/>
        <source>Recently &amp;Modified</source>
        <translation>ახლახანს &amp;შეცვლილი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="223"/>
        <source>&amp;Encoding</source>
        <translation>&amp;კოდირება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="305"/>
        <location filename="../../fpwin.cpp" line="4148"/>
        <location filename="../../replace.cpp" line="61"/>
        <location filename="../../replace.cpp" line="112"/>
        <source>Replacement</source>
        <translation>შემცვლელი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="538"/>
        <source>Focus/hide search bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="546"/>
        <source>&amp;Replace</source>
        <translation>&amp;ჩანაცვლება</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="725"/>
        <source>&amp;Other</source>
        <translation>&amp;სხვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="744"/>
        <source>&amp;UTF-8</source>
        <translation>&amp;UTF-8</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="755"/>
        <source>UTF-&amp;16</source>
        <translation>UTF-&amp;16</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="766"/>
        <source>&amp;ISO-8859-1</source>
        <translation>&amp;ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="824"/>
        <source>Close &amp;Other Tabs</source>
        <translation>&amp;სხვა ჩანართების დახურვა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="829"/>
        <source>&amp;Copy File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="834"/>
        <source>Copy File &amp;Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="845"/>
        <source>Alt+Right</source>
        <translation>Alt+მარჯვნივ</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="856"/>
        <source>Alt+Left</source>
        <translation>Alt+მარცხნივ</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="864"/>
        <source>&amp;First Tab</source>
        <translation>&amp;პირველი ჩანართი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="867"/>
        <source>Alt+Down</source>
        <translation>Alt+Down</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="875"/>
        <source>&amp;Last Tab</source>
        <translation>ბო&amp;ლო ჩანართი</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="878"/>
        <source>Alt+Up</source>
        <translation>Alt+მაღლა</translation>
    </message>
    <message>
        <location filename="../../fp.ui" line="883"/>
        <source>Menu</source>
        <translation>მენიუ</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="100"/>
        <source>Calculate number of words</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="115"/>
        <source>Next</source>
        <translation>შემდეგი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="116"/>
        <source>Previous</source>
        <translation>წინა</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="117"/>
        <source>Replace all</source>
        <translation>ყველას ჩანაცვლება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="632"/>
        <source>&amp;Recently Opened</source>
        <translation>&amp;ახახანს გახსნილი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2076"/>
        <source>Close</source>
        <translation>დახურვა</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1353"/>
        <source>Save changes?</source>
        <translation>შევინახო ცვლილებები?</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="997"/>
        <source>Please attend to that window or just close its dialog!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1357"/>
        <source>The document has been modified.</source>
        <translation>დოკუმენტი შეცვლილია.</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1368"/>
        <source>&amp;Discard changes</source>
        <translation>ცვლილებების &amp;მოცილება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1369"/>
        <source>&amp;Cancel</source>
        <translation>&amp;გაუქმება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1371"/>
        <source>&amp;No to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1579"/>
        <location filename="../../fpwin.cpp" line="1628"/>
        <source>Unsaved</source>
        <translation>შეუნახავი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2979"/>
        <location filename="../../fpwin.cpp" line="3682"/>
        <location filename="../../fpwin.cpp" line="3693"/>
        <location filename="../../fpwin.cpp" line="3700"/>
        <location filename="../../fpwin.cpp" line="4553"/>
        <location filename="../../fpwin.cpp" line="6172"/>
        <location filename="../../fpwin.cpp" line="6183"/>
        <location filename="../../fpwin.cpp" line="6190"/>
        <source>Lines</source>
        <translation>ხაზები</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="4554"/>
        <location filename="../../fpwin.cpp" line="4569"/>
        <source>Sel. Chars</source>
        <translation>მონ. სიმბოლოები</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="4556"/>
        <location filename="../../fpwin.cpp" line="4570"/>
        <source>Words</source>
        <translation>საკვანძო სიტყვები</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1969"/>
        <source>Another process is running in this tab!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2067"/>
        <source>Script File</source>
        <translation>სკრიპტის ფაილი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="996"/>
        <source>Another FeatherPad window has a modal dialog!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="833"/>
        <location filename="../../fpwin.cpp" line="4594"/>
        <source>Position:</source>
        <translation>მდებარეობა:</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="881"/>
        <location filename="../../fpwin.cpp" line="4612"/>
        <location filename="../../fpwin.cpp" line="4632"/>
        <source>Normal</source>
        <translation>ნორმალური</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1355"/>
        <location filename="../../fpwin.cpp" line="2742"/>
        <location filename="../../fpwin.cpp" line="5972"/>
        <source>The file does not exist.</source>
        <translation>ფაილი არ არსებობს.</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1740"/>
        <source>Open Link</source>
        <translation>ბმულის გახსნა</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1756"/>
        <source>Copy Link</source>
        <translation>Ბმულის კოპირება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="1970"/>
        <source>Only one process is allowed per tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2063"/>
        <source>Script Output</source>
        <translation>სკრიპტის გამოტანილი ინფორმაცია</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2079"/>
        <source>Clear</source>
        <translation>გაწმენდა</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2699"/>
        <source>FeatherPad does not open files larger than 100 MiB.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2707"/>
        <source>Non-text file(s) not opened!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2708"/>
        <source>See Preferences → Files → Do not permit opening of non-text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2717"/>
        <source>Some file(s) could not be opened!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2718"/>
        <source>You may not have the permission to read.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2728"/>
        <source>Uneditable file(s)!</source>
        <translation>ხაზები, რომლების ჩასწორებაც შეუძლებელია!</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2729"/>
        <source>Non-text files or files with huge lines cannot be edited.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2799"/>
        <source>Root Instance</source>
        <translation>ძირითადი გაშვებული ასლი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2880"/>
        <source>Open file...</source>
        <translation>ფაილის გახსნა...</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3115"/>
        <location filename="../../fpwin.cpp" line="3153"/>
        <source>Save as...</source>
        <translation>შენახვა როგორც...</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3189"/>
        <source>Keep encoding and save as...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3506"/>
        <source>Saving as root.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3507"/>
        <source>Waiting for authentication...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3626"/>
        <source>&quot;pkexec&quot; is not found. Please install Polkit!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3309"/>
        <source>Yes</source>
        <translation>კი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3310"/>
        <source>No</source>
        <translation>არა</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3311"/>
        <source>Cancel</source>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3312"/>
        <source>Do you want to use &lt;b&gt;MS Windows&lt;/b&gt; end-of-lines?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3313"/>
        <source>This may be good for readability under MS Windows.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3417"/>
        <location filename="../../fpwin.cpp" line="3521"/>
        <location filename="../../fpwin.cpp" line="3625"/>
        <location filename="../../fpwin.cpp" line="3637"/>
        <source>Cannot be saved!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="450"/>
        <location filename="../../fpwin.cpp" line="4042"/>
        <location filename="../../fpwin.cpp" line="5030"/>
        <location filename="../../fpwin.cpp" line="5291"/>
        <location filename="../../fpwin.cpp" line="6380"/>
        <source>Help</source>
        <translation>დახმარება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3678"/>
        <location filename="../../fpwin.cpp" line="3684"/>
        <location filename="../../fpwin.cpp" line="3692"/>
        <location filename="../../fpwin.cpp" line="4551"/>
        <location filename="../../fpwin.cpp" line="6168"/>
        <location filename="../../fpwin.cpp" line="6174"/>
        <location filename="../../fpwin.cpp" line="6182"/>
        <source>Syntax</source>
        <translation>სინტაქსი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2698"/>
        <source>Huge file(s) not opened!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2749"/>
        <source>Huge column!</source>
        <translation>უზარმაზარი სვეტი!</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2750"/>
        <source>Columns with more than 1000 rows are not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="2871"/>
        <location filename="../../fpwin.cpp" line="2876"/>
        <location filename="../../fpwin.cpp" line="3058"/>
        <location filename="../../fpwin.cpp" line="3064"/>
        <location filename="../../fpwin.cpp" line="3086"/>
        <source>All Files</source>
        <translation>ყველა ფაილი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3781"/>
        <source>Text tabs are converted to spaces.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3891"/>
        <source>The selected text was too long.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="3892"/>
        <source>It is not fully processed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="4054"/>
        <location filename="../../fpwin.cpp" line="4288"/>
        <source>This file has been modified elsewhere or in another way!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="4055"/>
        <location filename="../../fpwin.cpp" line="4289"/>
        <source>Please be careful about reloading or saving this document!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="4703"/>
        <source>Printing in progress...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="4754"/>
        <source>Print Document</source>
        <translation>დოკუმენტის დაბეჭდვა</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="4760"/>
        <source>Printing completed.</source>
        <translation>დაბეჭდვა დასრულდა.</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5424"/>
        <location filename="../../fpwin.cpp" line="5557"/>
        <source>%1 Pages</source>
        <translation>%1 გვერდი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5456"/>
        <location filename="../../fpwin.cpp" line="5593"/>
        <source>Copy Target Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5460"/>
        <location filename="../../fpwin.cpp" line="5597"/>
        <source>Open Target Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5479"/>
        <location filename="../../fpwin.cpp" line="5617"/>
        <source>Copy Final Target Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5483"/>
        <location filename="../../fpwin.cpp" line="5621"/>
        <source>Open Final Target Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5503"/>
        <location filename="../../fpwin.cpp" line="5642"/>
        <source>Open Containing Folder</source>
        <translation>შემცველი საქაღალდის გახსნა</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5768"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5769"/>
        <location filename="../../fpwin.cpp" line="5776"/>
        <location filename="../../fpwin.cpp" line="5786"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5775"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5785"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5808"/>
        <location filename="../../fpwin.cpp" line="5826"/>
        <location filename="../../fpwin.cpp" line="5841"/>
        <source>No misspelling in document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5810"/>
        <location filename="../../fpwin.cpp" line="5828"/>
        <location filename="../../fpwin.cpp" line="5843"/>
        <source>No misspelling from text cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="5859"/>
        <source>Spell Checking</source>
        <translation>მართლწერის შემოწმება</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="6206"/>
        <source>Some files cannot be saved!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="6246"/>
        <source>Translators</source>
        <translation>მთარგმნელები</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="6242"/>
        <source>A lightweight, tabbed, plain-text editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="6243"/>
        <source>based on Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="6244"/>
        <source>Author</source>
        <translation>ავტორი</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="6245"/>
        <source>aka.</source>
        <translation>ცნობილი, როგორც.</translation>
    </message>
    <message>
        <location filename="../../fpwin.cpp" line="6246"/>
        <location filename="../../fpwin.cpp" line="6247"/>
        <source>About FeatherPad</source>
        <translation>FeatherPad-ის შესახებ</translation>
    </message>
    <message>
        <location filename="../../replace.cpp" line="277"/>
        <source>No Replacement</source>
        <translation>ჩანაცვლების გარეშე</translation>
    </message>
    <message>
        <location filename="../../replace.cpp" line="279"/>
        <source>One Replacement</source>
        <translation>ერთი ჩანაცვლება</translation>
    </message>
    <message numerus="yes">
        <location filename="../../replace.cpp" line="281"/>
        <source>%Ln Replacements</source>
        <translation>
            <numerusform>%Ln ჩანაცვლება</numerusform>
            <numerusform>%Ln ჩანაცვლება</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../../replace.cpp" line="285"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../syntax.cpp" line="314"/>
        <source>The size limit for syntax highlighting is exceeded.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FeatherPad::FileDialog</name>
    <message>
        <location filename="../../filedialog.h" line="49"/>
        <source>Ctrl+H</source>
        <comment>Toggle showing hidden files</comment>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../filedialog.h" line="50"/>
        <source>Alt+.</source>
        <comment>Toggle showing hidden files</comment>
        <translation>Alt+.</translation>
    </message>
</context>
<context>
    <name>FeatherPad::FontDialog</name>
    <message>
        <location filename="../../fontDialog.ui" line="14"/>
        <source>Select Font</source>
        <translation>აირჩიეთ ფონტი</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="38"/>
        <source>Programming Fonts</source>
        <translation>პროგრამირების ფონტები</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="45"/>
        <location filename="../../fontDialog.ui" line="55"/>
        <source>Font:</source>
        <translation>ფონტი:</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="69"/>
        <source>Size:</source>
        <translation>ზომა:</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="89"/>
        <source>Weight:</source>
        <translation>წონა:</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="103"/>
        <source>Normal</source>
        <translation>ნორმალური</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="108"/>
        <source>Medium</source>
        <translation>საშუალო</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="113"/>
        <source>Bold</source>
        <translation>გასქელება</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="118"/>
        <source>Black</source>
        <translation>შავი</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="126"/>
        <source>Italic</source>
        <translation>დახრა</translation>
    </message>
    <message>
        <location filename="../../fontDialog.ui" line="149"/>
        <source>Preview</source>
        <translation>მინიატურა</translation>
    </message>
</context>
<context>
    <name>FeatherPad::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="34"/>
        <source>Clear text (Ctrl+K)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FeatherPad::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>მორგება</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="30"/>
        <source>Window</source>
        <translation>ფანჯარა</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="69"/>
        <source>Window Settings</source>
        <translation>ფანჯრის მორგება</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="75"/>
        <source>Remember window &amp;size on closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="84"/>
        <location filename="../../prefDialog.ui" line="97"/>
        <location filename="../../prefDialog.ui" line="107"/>
        <location filename="../../prefDialog.ui" line="120"/>
        <source>Window frame is excluded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="87"/>
        <source>Start with this size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="100"/>
        <location filename="../../prefDialog.ui" line="123"/>
        <source> px</source>
        <translation> პქს</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>×</source>
        <translation>×</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="148"/>
        <source>Enforcing a window position is not recommended
and may not work with some window managers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="152"/>
        <source>Remember window &amp;position on closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="159"/>
        <source>Most suitable with sessions
but without tab functionality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="188"/>
        <source>Uncheck for 1/5 of the width.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="191"/>
        <source>Remember splitter position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="200"/>
        <source>Do not show &amp;toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="207"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="211"/>
        <source>Do not show &amp;menubar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="218"/>
        <source>Double clicking on the title toggles the maximized state.
The title also has a right click menu when a file is opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="222"/>
        <source>Show window title on menubar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="229"/>
        <source>Menubar accelerators are activated by Alt
and may interfere with customized shortcuts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="233"/>
        <source>Disable menubar accelerators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="240"/>
        <source>Internal icons are used by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="243"/>
        <source>Use system icons where possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="250"/>
        <source>Hide search &amp;bar by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="257"/>
        <source>By default, each search entry
has a separate search history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="261"/>
        <source>Use a shared search history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>Always show st&amp;atus bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="293"/>
        <source>Show cursor position on status bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="304"/>
        <location filename="../../prefDialog.ui" line="314"/>
        <source>Will take effect after closing this dialog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>Tab position: </source>
        <translation>ჩანართის მდებარეობა: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="318"/>
        <source>North</source>
        <translation>ჩრდილოეთი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="323"/>
        <source>South</source>
        <translation>სამხრეთი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="328"/>
        <source>West</source>
        <translation>დასავლეთი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="333"/>
        <source>East</source>
        <translation>აღმოსავლეთი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="359"/>
        <source>This means that, for LTR, Alt+Right goes to the first tab
after the last tab is activated, and the same for Alt+Left.

Tab navigation with mouse wheel is not affected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="365"/>
        <source>Tab navigation wraps &amp;around</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="385"/>
        <source>Close window on closing its last tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="392"/>
        <source>By default, if a FeatherPad window exists on the
current desktop, files will be opened in its tabs.

However, some desktop environments may not
report that they have multiple desktops.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="399"/>
        <source>Always open in separate windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="406"/>
        <source>If this is checked, the file dialog provided by the current
desktop environment will be used instead of the Qt file dialog.

Some desktop environments, like KDE and LXQt, provide files dialogs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="412"/>
        <source>Native file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="488"/>
        <source>Uncheck for Monospace.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="491"/>
        <source>Remember &amp;font</source>
        <translation>&amp;ფონტის დამახსოვრება</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="512"/>
        <source>This covers parentheses, braces, brackets and quotes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="515"/>
        <source>Auto-&amp;bracket</source>
        <translation>ფრჩხილე&amp;ბის ავტომატური დახურვა</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="522"/>
        <source>By default, a triple period is replaced with an ellipsis
and a double hyphen with a long dash while typing,
under proper circumstances.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="527"/>
        <source>Replace triple periods and double hyphens while typing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="541"/>
        <source>Highlight case-sensitive and whole matches
of the selected text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="545"/>
        <source>Selection highlighting</source>
        <translation>მონიშნულის გამოკვეთა</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="608"/>
        <source>Never highlight syntax for files &gt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="577"/>
        <source>This creates a menu button on the
status bar for changing the syntax.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="581"/>
        <source>Support syntax override</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="646"/>
        <source>Show spaces, tabs and tab lines
when the syntax is highlighted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="650"/>
        <source>Show whitespaces</source>
        <translation>თეთრი ჰარეების ჩვენება</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="666"/>
        <location filename="../../prefDialog.ui" line="677"/>
        <source>The vertical position lines will be drawn only if
the editor font has a fixed pitch (like Monospace).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="670"/>
        <source>Show vertical lines starting from this position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="657"/>
        <source>Show line and document ends</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="801"/>
        <source>Date and time format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="869"/>
        <source>Some text editors cannot open a document
whose last line is not empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="873"/>
        <source>Ensure an empty last line on saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="880"/>
        <source>Remove trailing spaces on saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="898"/>
        <source>Inertial scrolling with mouse wheel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="987"/>
        <source>Files</source>
        <translation>ფაილი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="993"/>
        <source>File Management</source>
        <translation>ფაილების მართვა</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1110"/>
        <source>Start with files of last window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1152"/>
        <location filename="../../prefDialog.ui" line="1171"/>
        <source>This can be any starting command with
arguments, for example, &quot;xterm -hold&quot;
for running the process in XTerm.

If the command is left empty, the file
will be executed directly.

If the script is not run in a terminal
emulator, the output and error messages
will be shown by a popup dialog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1164"/>
        <source>Start with this command: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1183"/>
        <source>Command + Arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1068"/>
        <source>Show recentl&amp;y modified files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1098"/>
        <source>Show recentl&amp;y opened files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1197"/>
        <source>Save changes to opened files every:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1475"/>
        <source>Help</source>
        <translation>დახმარება</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="163"/>
        <source>Start with side-pane mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="372"/>
        <source>If this is checked, not only you will lose the informative
tooltip and context menu of a single tab but you could not
merge a single tabbed window into another one by tab drag-
and-drop either.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="378"/>
        <source>&amp;Do not show a single tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Text</source>
        <translation>ტექსტი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="482"/>
        <source>Text Editor</source>
        <translation>ტექსტური რედაქტორი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="498"/>
        <source>&amp;Wrap lines by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="505"/>
        <source>Auto-&amp;indent by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="534"/>
        <source>Always show line &amp;numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="552"/>
        <source>Highlight s&amp;yntax by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="712"/>
        <source>Dark c&amp;olor scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="747"/>
        <source>Background color value: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="615"/>
        <source> MiB</source>
        <translation> მიბ</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1117"/>
        <source>This only includes executable files written
in script languages like Shell and Python.

If it is checked and the opened file is
executable, the file will be executed by clicking
the Run button, that appears on the toolbar/filemenu
when needed, or by its shortcut Ctrl+E. Then, the
process could be killed by Ctrl+Alt+E.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="709"/>
        <source>Needs window reopening to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="737"/>
        <location filename="../../prefDialog.ui" line="754"/>
        <source>The color value of the background.
255 means white while 0 means black.

For the light background, it can be
between 230 and 255; for the dark
background, between 0 and 50.

Needs window reopening to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1127"/>
        <source>Run executable scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1001"/>
        <location filename="../../prefDialog.ui" line="1015"/>
        <source>The maximum number of recently modified or
opened files FeatherPad shows. The default
is 10.

Needs application restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="786"/>
        <source>Add a small margin around text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="795"/>
        <location filename="../../prefDialog.ui" line="808"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="828"/>
        <source>Text tab size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="835"/>
        <source> spaces</source>
        <translation> ჰარე</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="887"/>
        <source>Thick text cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="894"/>
        <source>Should the mouse wheel scrolling be inertial
if the cursor is inside the text view?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="905"/>
        <source>Spell Checking</source>
        <translation>მართლწერის შემოწმება</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="913"/>
        <location filename="../../prefDialog.ui" line="925"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="918"/>
        <source>Hunspell dictionary path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="937"/>
        <location filename="../../pref.cpp" line="1802"/>
        <source>Add dictionary...</source>
        <translation>ლექსიკონის დამატება...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="949"/>
        <source>If this is unchecked, spell checking
will be started from the document start.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="953"/>
        <source>Start spell checking from text cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1008"/>
        <source>Number of recent files: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1107"/>
        <source>Only if their number is not greater than 50.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1194"/>
        <location filename="../../prefDialog.ui" line="1204"/>
        <source>Only for files that exist and can be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1207"/>
        <source> min</source>
        <translation> წთ</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1238"/>
        <source>If this is checked, the Save button/menu-item could
be used also when the opened file is not modified.

This can be useful under certain circumstances,
e.g. for changing the time stamp or removing the
trailing spaces of a text file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1246"/>
        <source>Allow saving unmodified files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1253"/>
        <source>Show a warning instead.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1256"/>
        <source>Do not permit opening of non-text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1263"/>
        <source>By default, when files are copied, they will
be opened if they are pasted into FeatherPad.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1267"/>
        <source>Paste paths instead of files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1294"/>
        <source>Shortcuts</source>
        <translation>მალსახმობი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1316"/>
        <source>Action</source>
        <translation>პარამეტრები</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1321"/>
        <source>Shortcut</source>
        <translation>მალმხმობი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1329"/>
        <source>Restore default shortcuts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1332"/>
        <location filename="../../prefDialog.ui" line="1406"/>
        <location filename="../../prefDialog.ui" line="1454"/>
        <source>Default</source>
        <translation>ნაგულისხმევი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1343"/>
        <source>Syntax Colors</source>
        <translation>სინტაქსის ფერები</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1438"/>
        <source>Element</source>
        <translation>ელემენტი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1443"/>
        <source>Text Color</source>
        <translation>ტექსტის ფერი</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1360"/>
        <source>Whitespace color value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1393"/>
        <location filename="../../prefDialog.ui" line="1403"/>
        <source>Has effect only if line numbers are shown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1396"/>
        <source>Current line highlight value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1451"/>
        <source>Restore default syntax colors.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="1486"/>
        <source>Close</source>
        <translation>დახურვა</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="113"/>
        <source>Press a modifier key to clear a shortcut
in the editing mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="119"/>
        <source>Double click a color to change it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="355"/>
        <location filename="../../pref.cpp" line="1498"/>
        <source>files</source>
        <translation>ფაილები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="355"/>
        <location filename="../../pref.cpp" line="1498"/>
        <source>file</source>
        <translation>ფაილი</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="422"/>
        <location filename="../../pref.cpp" line="1617"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="455"/>
        <source>Functions, URLs,…</source>
        <translation>ფუნქციები, ბმულები…</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="456"/>
        <source>Built-in Functions</source>
        <translation>ჩაშენებული ფუნქციები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="457"/>
        <source>Comments</source>
        <translation>კომენტარები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="458"/>
        <source>Quotations</source>
        <translation>ციტატები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="459"/>
        <source>Types</source>
        <translation>ტიპები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="460"/>
        <source>Key Words</source>
        <translation>საკვანძო სიტყვები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="461"/>
        <source>Numbers</source>
        <translation>რიცხვები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="462"/>
        <source>Regular Expressions, Code Blocks,…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="463"/>
        <source>Document Blocks, XML/HTML Elements,…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="464"/>
        <source>Markdown Headings, CSS Values,…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="465"/>
        <source>Extra Elements</source>
        <translation>დამატებითი ელემენტები</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="647"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="668"/>
        <source>Window reopening is needed for changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="1524"/>
        <source>&amp;Recently Opened</source>
        <translation>&amp;ახლახანს გახსნილი</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="1525"/>
        <source>Recently &amp;Modified</source>
        <translation>ახლახან &amp;შეცვლილი</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="1600"/>
        <source>The typed shortcut was reserved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="1804"/>
        <source>Hunspell Dictionary Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="523"/>
        <location filename="../../pref.cpp" line="1890"/>
        <source>Select Syntax Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FeatherPad::SearchBar</name>
    <message>
        <location filename="../../searchbar.cpp" line="94"/>
        <location filename="../../searchbar.cpp" line="173"/>
        <source>Search...</source>
        <translation>ძებნა...</translation>
    </message>
    <message>
        <location filename="../../searchbar.cpp" line="125"/>
        <source>Match Case</source>
        <translation>რეგისტრის დამთხვევა</translation>
    </message>
    <message>
        <location filename="../../searchbar.cpp" line="132"/>
        <source>Whole Word</source>
        <translation>მთლიანი სიტყვა</translation>
    </message>
    <message>
        <location filename="../../searchbar.cpp" line="139"/>
        <source>Regular Expression</source>
        <translation>რეგულარული ექსპრესია</translation>
    </message>
    <message>
        <location filename="../../searchbar.cpp" line="171"/>
        <source>Search with regex...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../searchbar.cpp" line="120"/>
        <source>Next</source>
        <translation>შემდეგი</translation>
    </message>
    <message>
        <location filename="../../searchbar.cpp" line="121"/>
        <source>Previous</source>
        <translation>წინა</translation>
    </message>
</context>
<context>
    <name>FeatherPad::SessionDialog</name>
    <message>
        <location filename="../../sessionDialog.ui" line="14"/>
        <source>Session Manager</source>
        <translation>სესსის მმართველი</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="113"/>
        <location filename="../../sessionDialog.ui" line="294"/>
        <source>&amp;Remove</source>
        <translation>&amp;წაშლა</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="45"/>
        <source>&lt;b&gt;Save/Restore Session&lt;/b&gt;</source>
        <translation>&lt;b&gt;სესიის შენახვა/აღდგენა&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="68"/>
        <source>Filter...</source>
        <translation>გაფილტვრა...</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="81"/>
        <source>Open the selected session(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="84"/>
        <location filename="../../sessionDialog.ui" line="299"/>
        <source>&amp;Open</source>
        <translation>&amp;გახსნა</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="110"/>
        <location filename="../../sessionDialog.ui" line="120"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="127"/>
        <location filename="../../sessionDialog.ui" line="137"/>
        <source>Ctrl+Del</source>
        <translation>Ctrl+Del</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="171"/>
        <source>By default, all files that are opened in all
windows will be included in the saved session.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="175"/>
        <source>Save only from this &amp;window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="204"/>
        <source>&lt;b&gt;Warning&lt;/b&gt;</source>
        <translation>&lt;b&gt;გაფრთხილება&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="250"/>
        <location filename="../../session.cpp" line="332"/>
        <source>&amp;Yes</source>
        <translation>&amp;დიახ</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="257"/>
        <source>&amp;No</source>
        <translation>&amp;არა</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="307"/>
        <source>Re&amp;name</source>
        <translation>სახე&amp;ლის გადარქმევა</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="130"/>
        <source>Remove &amp;All</source>
        <translation>&amp;ყველას წაშლა</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="284"/>
        <source>&amp;Close</source>
        <translation>&amp;დახურვა</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="147"/>
        <source>Save the current session under the given title.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="150"/>
        <source>&amp;Save</source>
        <translation>&amp;შენახვა</translation>
    </message>
    <message>
        <location filename="../../sessionDialog.ui" line="161"/>
        <source>Type a name to save session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="183"/>
        <source>Nothing saved.&lt;br&gt;No file was opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="281"/>
        <source>No file exists or can be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="283"/>
        <source>Not all files exist or can be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="318"/>
        <source>&amp;OK</source>
        <translation>&amp;დიახ</translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="337"/>
        <source>Do you really want to remove all saved sessions?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="343"/>
        <source>Do you really want to remove the selected sessions?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="345"/>
        <source>Do you really want to remove the selected session?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../session.cpp" line="350"/>
        <source>A session with the same name exists.&lt;br&gt;Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FeatherPad::SidePane</name>
    <message>
        <location filename="../../sidepane.cpp" line="196"/>
        <source>Filter...</source>
        <translation>გაფილტვრა...</translation>
    </message>
</context>
<context>
    <name>FeatherPad::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>უცნობი სიტყვა:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>ჩანაცვლდება:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>ერთხელ შესწორება</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>ერთხელ გამოტოვება</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>ყველას იგნორირება</translation>
    </message>
</context>
<context>
    <name>FeatherPad::TextEdit</name>
    <message>
        <location filename="../../textedit.cpp" line="152"/>
        <source>Double click to center current line</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
